package com.sky.ioc.service.supermarket.impl;

import com.alibaba.fastjson.JSONObject;
import com.sky.ioc.entity.Indeicator;
import com.sky.ioc.entity.Label;
import com.sky.ioc.entity.domain.supermarket.SupermarketOrder;
import com.sky.ioc.entity.params.IocParam;
import com.sky.ioc.mapper.SupermarketOrderMapper;
import com.sky.ioc.service.supermarket.SupermarketService;
import com.sky.ioc.tool.FalseData;
import com.sky.ioc.tool.GeneralMethod;
import com.sky.ioc.tool.ReturnMsg;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ThreadLocalRandom;

/**
 * TODO
 *
 * @Description
 * @Author LunCe
 * @Date 2023/2/10 14:19
 **/
@Service
public class SupermarketServiceImpl implements SupermarketService {

    @Autowired
    private SupermarketOrderMapper supermarketOrderMapper;

    @Override
    public ReturnMsg getCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        Double totalPrice = supermarketOrderMapper.getTotalPriceByCompanyIdAndDeptId(iocParam);
        totalPrice = totalPrice == null ? 0 : totalPrice;
        BigDecimal bigDecimal = new BigDecimal(totalPrice);
        // 转换为万元(除以10000)保留两位小数
        BigDecimal decimal = bigDecimal.divide(new BigDecimal("10000"), 2, RoundingMode.HALF_UP);
        totalPrice = decimal.doubleValue();
        Integer totalOrder = supermarketOrderMapper.getTotalOrderByCompanyIdAndDeptId(iocParam);
        Integer totalPerson = supermarketOrderMapper.getTotalPersonByCompanyIdAndDeptId(iocParam);
        double avgPrice = 0d;
        double avgPersonPrice = 0d;
        if (totalPrice > 0) {
            if (totalOrder > 0) {
                BigDecimal avgPriceDec = bigDecimal.divide(new BigDecimal(totalOrder), 2, RoundingMode.HALF_UP);
                avgPrice = avgPriceDec.doubleValue();
            }
            if (totalPerson > 0) {
                BigDecimal avgPersonPriceDec = bigDecimal.divide(new BigDecimal(totalPerson), 2, RoundingMode.HALF_UP);
                avgPersonPrice = avgPersonPriceDec.doubleValue();
            }
        }
        ThreadLocalRandom random = ThreadLocalRandom.current();
        double compare = random.nextDouble(-1, 1);
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        compare = Double.parseDouble(decimalFormat.format(compare));
        objects.get(0).put("value", totalPrice);
        objects.get(0).put("compare", compare);

        objects.get(1).put("value", totalOrder);
        objects.get(1).put("compare", compare);

        objects.get(2).put("value", avgPersonPrice);
        objects.get(2).put("compare", compare);

        objects.get(3).put("value", avgPrice);
        objects.get(3).put("compare", compare);
        indeicator.setWorthAttention("本月盈利将达12万元");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getQuotientAnalysiss(IocParam iocParam) {
        String[] param = {"morningTotal", "afternoonTotal", "morningOrder", "afternoonOrder", "averageOrder"};
        String[] labKey = {"1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"};
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getProductRanking(IocParam iocParam) {
        List<Map<String, String>> list = supermarketOrderMapper.getListByCompanyIdAndDeptId(iocParam);
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getSupermarketInfoList() {
        String[] param = {"consumptionAmount", "consumptionOrder"};
        String[] labKey = {"1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"};
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getSupermarketCoreIndicators() {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        Double totalPrice = supermarketOrderMapper.getTotalPriceByCompanyIdAndDeptId(null);
        totalPrice = totalPrice == null ? 0 : Double.valueOf(decimalFormat.format(totalPrice));
        BigDecimal bigDecimal = new BigDecimal(totalPrice);
        Integer totalOrder = supermarketOrderMapper.getTotalOrderByCompanyIdAndDeptId(null);
        double avgPrice = 0d;
        if (totalPrice > 0) {
            BigDecimal avgPriceDec = bigDecimal.divide(new BigDecimal(totalOrder), 2, RoundingMode.HALF_UP);
            avgPrice = avgPriceDec.doubleValue();
        }
        ThreadLocalRandom random = ThreadLocalRandom.current();
        Double thirdPay = supermarketOrderMapper.getThirdTotalPriceByCompanyIdAndDeptId();
        thirdPay = thirdPay == null ? 0 : Double.valueOf(decimalFormat.format(thirdPay));
        double compare = random.nextDouble(-1, 1);
        compare = Double.parseDouble(decimalFormat.format(compare));

        objects.get(0).put("value", totalPrice);
        objects.get(0).put("compare", compare);

        objects.get(1).put("value", totalOrder);
        objects.get(1).put("compare", compare);

        objects.get(2).put("value", avgPrice);
        objects.get(2).put("compare", compare);

        objects.get(3).put("value", thirdPay);

        indeicator.setWorthAttention("提高合同额");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }
}
